@@ -43,6 +43,7 @@ else:
 __all__ = (
     "AddNotificationChannelRequestRequestTypeDef",
     "AddNotificationChannelResponseTypeDef",
+    "AnomalyReportedTimeRangeTypeDef",
     "AnomalySourceDetailsTypeDef",
     "AnomalyTimeRangeTypeDef",
     "CloudFormationCollectionFilterTypeDef",
@@ -150,6 +151,27 @@ AddNotificationChannelResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredAnomalyReportedTimeRangeTypeDef = TypedDict(
+    "_RequiredAnomalyReportedTimeRangeTypeDef",
+    {
+        "OpenTime": datetime,
+    },
+)
+_OptionalAnomalyReportedTimeRangeTypeDef = TypedDict(
+    "_OptionalAnomalyReportedTimeRangeTypeDef",
+    {
+        "CloseTime": datetime,
+    },
+    total=False,
+)
+
+
+class AnomalyReportedTimeRangeTypeDef(
+    _RequiredAnomalyReportedTimeRangeTypeDef, _OptionalAnomalyReportedTimeRangeTypeDef
+):
+    pass
+
+
 AnomalySourceDetailsTypeDef = TypedDict(
     "AnomalySourceDetailsTypeDef",
     {
@@ -775,6 +797,7 @@ ProactiveAnomalySummaryTypeDef = TypedDict(
         "Status": AnomalyStatusType,
         "UpdateTime": datetime,
         "AnomalyTimeRange": "AnomalyTimeRangeTypeDef",
+        "AnomalyReportedTimeRange": "AnomalyReportedTimeRangeTypeDef",
         "PredictionTimeRange": "PredictionTimeRangeTypeDef",
         "SourceDetails": "AnomalySourceDetailsTypeDef",
         "AssociatedInsightId": str,
@@ -792,6 +815,7 @@ ProactiveAnomalyTypeDef = TypedDict(
         "Status": AnomalyStatusType,
         "UpdateTime": datetime,
         "AnomalyTimeRange": "AnomalyTimeRangeTypeDef",
+        "AnomalyReportedTimeRange": "AnomalyReportedTimeRangeTypeDef",
         "PredictionTimeRange": "PredictionTimeRangeTypeDef",
         "SourceDetails": "AnomalySourceDetailsTypeDef",
         "AssociatedInsightId": str,
@@ -846,6 +870,7 @@ ReactiveAnomalySummaryTypeDef = TypedDict(
         "Severity": AnomalySeverityType,
         "Status": AnomalyStatusType,
         "AnomalyTimeRange": "AnomalyTimeRangeTypeDef",
+        "AnomalyReportedTimeRange": "AnomalyReportedTimeRangeTypeDef",
         "SourceDetails": "AnomalySourceDetailsTypeDef",
         "AssociatedInsightId": str,
         "ResourceCollection": "ResourceCollectionTypeDef",
@@ -860,6 +885,7 @@ ReactiveAnomalyTypeDef = TypedDict(
         "Severity": AnomalySeverityType,
         "Status": AnomalyStatusType,
         "AnomalyTimeRange": "AnomalyTimeRangeTypeDef",
+        "AnomalyReportedTimeRange": "AnomalyReportedTimeRangeTypeDef",
         "SourceDetails": "AnomalySourceDetailsTypeDef",
         "AssociatedInsightId": str,
         "ResourceCollection": "ResourceCollectionTypeDef",
